@@ -1,4 +1,4 @@
-# Copyright © 2022 Gurobi Optimization, LLC
+# Copyright © 2023 Gurobi Optimization, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,7 +41,8 @@ class AbstractNNLayer(AbstractPredictorConstr):
             self, gp_model, input_vars, output_vars, **kwargs
         )
 
-    def get_error(self):
+    def get_error(self, eps=None):
+        # We can't compute externally the error of a layer
         assert False
 
     def print_stats(self, abbrev=False, file=None):
@@ -80,7 +81,7 @@ class ActivationLayer(AbstractNNLayer):
     def _create_output_vars(self, input_vars):
         rval = self._gp_model.addMVar(input_vars.shape, lb=-gp.GRB.INFINITY, name="act")
         self._gp_model.update()
-        self._output = rval
+        return rval
 
     def _mip_model(self, **kwargs):
         """Add the layer to model."""
@@ -126,7 +127,7 @@ class DenseLayer(AbstractNNLayer):
             (input_vars.shape[0], self.coefs.shape[1]), lb=-gp.GRB.INFINITY, name="act"
         )
         self._gp_model.update()
-        self._output = rval
+        return rval
 
     def _mip_model(self, **kwargs):
         """Add the layer to model."""
