@@ -1,4 +1,4 @@
-# Copyright © 2022 Gurobi Optimization, LLC
+# Copyright © 2023 Gurobi Optimization, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -118,18 +118,38 @@ class SubModel:
         if not hasattr(self, "_default_name"):
             self._default_name = type(self).__name__
 
+        self.verbose = False
         if "verbose" in kwargs:
             self.verbose = kwargs["verbose"]
-            self._start_time = time()
-        else:
-            self.verbose = False
+            self._timer = SubModel._ModelingTimer()
+            print()
+            self._timer.timing(f"Start building formulation for {self._default_name}")
 
+        self._no_recording = False
+        if "no_record" in kwargs:
+            self._no_recording = kwargs["no_record"]
+
+        self._no_debug = False
+        if "no_debug" in kwargs:
+            self._no_debug = kwargs["no_debug"]
         before = self._open(gp_model)
+
+        if self.verbose:
+            self._timer.timing("Model statistics")
+
         self._objects = self._build_submodel(gp_model, *args, **kwargs)
+
+        if self.verbose:
+            self._timer.timing("Built model")
+
         if self._objects is None:
             self._objects = {}
+
         self._close(before, name)
 
+        if self.verbose:
+            print()
+
     def _build_submodel(self, gp_model, *args, **kwargs):
         """Method to be overridden for generating the model in a sub-class.
 
@@ -138,6 +158,18 @@ class SubModel:
         """
         return self._model_function(gp_model, *args, **kwargs)
 
+    class _ModelingTimer:
+        def __init__(self):
+            self.start = time()
+            self.last = self.start
+
+        def timing(self, message: str):
+            current = time()
+            print(
+                f"{message} in {current - self.last:.2f} secs (total: {current - self.start:.2f})."
+            )
+            self.last = current
+
     class _ModelingData:
         """Class for recording modeling data in a gurobipy.Model object."""
 
@@ -263,7 +295,11 @@ class SubModel:
             modeling_data = SubModel._ModelingData()
         gp_model._modeling_data = modeling_data
 
-        return (self._modelstats(gp_model), gp_model._modeling_data.pop_name_handler())
+        if self._no_recording:
+            modelstats = None
+        else:
+            modelstats = self._modelstats(gp_model)
+        return (modelstats, gp_model._modeling_data.pop_name_handler())
 
     def _close(self, before, name):
         """Finalize addition of modeling objects to the gurobipy.Model object.
@@ -277,15 +313,17 @@ class SubModel:
             def __init__(self):
                 self.name = {}
 
-            def get_name(self, sub: SubModel):
+            def get_name(self, sub: SubModel, name: str):
                 """Return a default name for specified submodel sub."""
-                name = sub.default_name
+                if name is None or name == "":
+                    name = sub.default_name
                 try:
                     num = self.name[name]
+                    self.name[name] = num + 1
+                    return f"{name}{num}"
                 except KeyError:
-                    num = 1
-                self.name[name] = num + 1
-                return f"{name}{num}"
+                    self.name[name] = 0
+                    return name
 
         def prefix_names(gp_model, objs, attr, name):
             """Prefix all modeling object names with name."""
@@ -298,27 +336,31 @@ class SubModel:
         # re-install name handler
         self._gp_model._modeling_data.push_name_handler(before[1])
 
+        if self._no_recording:
+            return
+
         # record all newly added modeling objects
         self._record(self._gp_model, before[0])
 
-        # prefix names of newly created modeling objects
+        name_handler = self._gp_model._modeling_data.name_handler
+        if name_handler is None:
+            name_handler = NameHandler()
+            self._gp_model._modeling_data.push_name_handler(name_handler)
+
         if name != "":
-            if name is None:
-                name_handler = self._gp_model._modeling_data.name_handler
-                if name_handler is None:
-                    name_handler = NameHandler()
-                    self._gp_model._modeling_data.push_name_handler(name_handler)
-                name = name_handler.get_name(self)
+            # prefix names of newly created modeling objects
+            name = name_handler.get_name(self, name)
             self._name = name
-            if self.verbose:
-                gen_time = time() - self._start_time
-                print(f"Added {name} took {gen_time:.2f} seconds.")
             prefix_names(self._gp_model, self.vars, "VarName", name)
             prefix_names(self._gp_model, self.constrs, "ConstrName", name)
             prefix_names(self._gp_model, self.qconstrs, "QCName", name)
             prefix_names(self._gp_model, self.genconstrs, "GenConstrName", name)
             # SOS can't have a name! :-O
             # prefix_names(self._gp_model, self.sos, "SOSName", name)
+        else:
+            name = name_handler.get_name(self, name)
+        if self.verbose:
+            self._timer.timing(f"Added {name}")
 
     def print_stats(self, abbrev=False, file=None):
         """Print statistics about submodel.
