@@ -1,4 +1,4 @@
-# Copyright © 2022 Gurobi Optimization, LLC
+# Copyright © 2023 Gurobi Optimization, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,7 +28,9 @@ def sklearn_convertors():
         from .sklearn.predictors_list import (  # pylint: disable=import-outside-toplevel
             sklearn_predictors,
         )
-        from .sklearn.preprocessing import sklearn_transformers
+        from .sklearn.preprocessing import (
+            sklearn_transformers,  # pylint: disable-import-outside-toplevel
+        )
 
         return (
             sklearn_predictors()
@@ -53,23 +55,33 @@ def pytorch_convertors():
     return {}
 
 
+def xgboost_convertors():
+    """Collect known PyTorch objects that can be formulated and the conversion class."""
+    if "xgboost" in sys.modules:
+        import xgboost as xgb  # pylint: disable=import-outside-toplevel
+
+        from .xgboost import (  # pylint: disable=import-outside-toplevel
+            add_xgboost_regressor_constr,
+            add_xgbrfregressor_constr,
+        )
+
+        return {
+            xgb.core.Booster: add_xgboost_regressor_constr,
+            xgb.XGBRFRegressor: add_xgbrfregressor_constr,
+        }
+    return {}
+
+
 def keras_convertors():
     """Collect known Keras objects that can be embedded and the conversion class."""
     if "tensorflow" in sys.modules:
-        from keras.engine.functional import (  # pylint: disable=import-outside-toplevel
-            Functional,
-        )
-        from keras.engine.training import (  # pylint: disable=import-outside-toplevel
-            Model,
-        )
         from tensorflow import keras  # pylint: disable=import-outside-toplevel
 
         from .keras import add_keras_constr  # pylint: disable=import-outside-toplevel
 
         return {
             keras.Sequential: add_keras_constr,
-            Functional: add_keras_constr,
-            Model: add_keras_constr,
+            keras.Model: add_keras_constr,
         }
     return {}
 
@@ -80,5 +92,6 @@ def registered_predictors():
     convertors |= sklearn_convertors()
     convertors |= pytorch_convertors()
     convertors |= keras_convertors()
+    convertors |= xgboost_convertors()
     convertors |= user_predictors()
     return convertors
