@@ -1,4 +1,4 @@
-# Copyright © 2022 Gurobi Optimization, LLC
+# Copyright © 2023 Gurobi Optimization, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,10 +18,12 @@
 in a :gurobipy:`model`.
 """
 
-import numpy as np
-from gurobipy import GRB
 
 from ..modeling import AbstractPredictorConstr
+from ..modeling.decision_tree.decision_tree_model import (
+    leaf_formulation,
+    paths_formulation,
+)
 from .skgetter import SKgetter
 
 
@@ -31,9 +33,7 @@ def add_decision_tree_regressor_constr(
     input_vars,
     output_vars=None,
     epsilon=0.0,
-    scale=1.0,
-    float_type=np.float32,
-    **kwargs
+    **kwargs,
 ):
     """Formulate decision_tree_regressor into gp_model.
 
@@ -54,12 +54,6 @@ def add_decision_tree_regressor_constr(
     epsilon : float, optional
         Small value used to impose strict inequalities for splitting nodes in
         MIP formulations.
-    scale : float, optional
-        Value
-    float_type : type, optional
-        Float type for the thresholds defining the node splits in the MIP
-        formulation
-
     Returns
     -------
     DecisionTreeRegressorConstr
@@ -79,14 +73,7 @@ def add_decision_tree_regressor_constr(
     this point.
     """
     return DecisionTreeRegressorConstr(
-        gp_model,
-        decision_tree_regressor,
-        input_vars,
-        output_vars,
-        epsilon,
-        scale,
-        float_type,
-        **kwargs
+        gp_model, decision_tree_regressor, input_vars, output_vars, epsilon, **kwargs
     )
 
 
@@ -104,15 +91,19 @@ class DecisionTreeRegressorConstr(SKgetter, AbstractPredictorConstr):
         predictor,
         input_vars,
         output_vars=None,
-        epsilon=1e-6,
-        scale=1.0,
-        float_type=np.float32,
-        **kwargs
+        epsilon=0.0,
+        formulation="leafs",
+        **kwargs,
     ):
         self.epsilon = epsilon
-        self.scale = scale
-        self.float_type = float_type
         self._default_name = "tree_reg"
+
+        formulations = ("leafs", "paths")
+        if formulation not in formulations:
+            raise ValueError(
+                "Wrong value for formulation should be one of {}.".format(formulations)
+            )
+        self._formulation = formulation
         SKgetter.__init__(self, predictor, input_vars)
         AbstractPredictorConstr.__init__(
             self, gp_model, input_vars, output_vars, **kwargs
@@ -120,71 +111,34 @@ class DecisionTreeRegressorConstr(SKgetter, AbstractPredictorConstr):
 
     def _mip_model(self, **kwargs):
         tree = self.predictor.tree_
-        model = self._gp_model
+        timer = AbstractPredictorConstr._ModelingTimer()
 
-        _input = self._input
-        output = self._output
-        outdim = output.shape[1]
-        nex = _input.shape[0]
-        nodes = model.addMVar((nex, tree.capacity), vtype=GRB.BINARY, name="node")
-
-        # Collect leafs and non-leafs nodes
-        notleafs = tree.children_left >= 0
-        leafs = tree.children_left < 0
-
-        # Connectivity constraint
-        model.addConstr(
-            nodes[:, notleafs]
-            == nodes[:, tree.children_right[notleafs]]
-            + nodes[:, tree.children_left[notleafs]]
-        )
-
-        # The value of the root is always 1
-        nodes[:, 0].LB = 1.0
-
-        # Node splitting
-        for node in notleafs.nonzero()[0]:
-            left = tree.children_left[node]
-            right = tree.children_right[node]
-            threshold = tree.threshold[node]
-            threshold = self.float_type(threshold)
-            scale = max(abs(1 / threshold), self.scale)
-            # Intermediate node
-            feature = tree.feature[node]
-            feat_var = _input[:, feature]
-
-            fixed_input = (feat_var.UB == feat_var.LB).all()
-
-            if fixed_input:
-                # Special case where we have an MVarPlusConst object
-                # If that feature is a constant we can directly fix it.
-                value = _input[:, feature].LB
-                fixed_left = value <= threshold
-                nodes[fixed_left, right].UB = 0.0
-                nodes[~fixed_left, left].UB = 0.0
-            else:
-                lhs = _input[:, feature].tolist()
-                rhs = nodes[:, left].tolist()
-                threshold *= scale
-                model.addConstrs(
-                    ((rhs[k] == 1) >> (scale * lhs[k] <= threshold)) for k in range(nex)
-                )
-                rhs = nodes[:, right].tolist()
-                model.addConstrs(
-                    ((rhs[k] == 1) >> (scale * lhs[k] >= threshold + self.epsilon))
-                    for k in range(nex)
-                )
-
-        for node in leafs.nonzero()[0]:
-            # Leaf node:
-            lhs = output.tolist()
-            rhs = nodes[:, node].tolist()
-            value = tree.value[node, :, 0]
-            model.addConstrs(
-                (rhs[k] == 1) >> (lhs[k][i] == value[i])
-                for k in range(nex)
-                for i in range(outdim)
+        tree_dict = {
+            "children_left": tree.children_left,
+            "children_right": tree.children_right,
+            "feature": tree.feature,
+            "threshold": tree.threshold,
+            "value": tree.value[:, :, 0],
+            "capacity": tree.capacity,
+            "n_features": tree.n_features,
+        }
+        if self._formulation == "leafs":
+            return leaf_formulation(
+                self.gp_model,
+                self.input,
+                self.output,
+                tree_dict,
+                self.epsilon,
+                self._name_var,
+                self.verbose,
+                timer,
+            )
+        else:
+            return paths_formulation(
+                self.gp_model,
+                self.input,
+                self.output,
+                tree_dict,
+                self.epsilon,
+                self._name_var,
             )
-
-        output.LB = np.min(tree.value)
-        output.UB = np.max(tree.value)
