@@ -1,4 +1,4 @@
-# Copyright © 2022 Gurobi Optimization, LLC
+# Copyright © 2023 Gurobi Optimization, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -99,23 +99,30 @@ class GradientBoostingRegressorConstr(SKgetter, AbstractPredictorConstr):
             outdim == 1
         ), "Output dimension of gradient boosting regressor should be 1"
 
-        treevars = model.addMVar(
-            (nex, predictor.n_estimators_, 1), lb=-GRB.INFINITY, name="estimator"
-        )
-        constant = predictor.init_.constant_
-
         estimators = []
+        if self._no_debug:
+            kwargs["no_record"] = True
+
+        tree_vars = model.addMVar(
+            (nex, predictor.n_estimators_, 1),
+            lb=-GRB.INFINITY,
+            name=self._name_var("esimator"),
+        )
+
         for i in range(predictor.n_estimators_):
             tree = predictor.estimators_[i]
+            if self.verbose:
+                self._timer.timing(f"Estimator {i}")
             estimators.append(
                 add_decision_tree_regressor_constr(
-                    model, tree[0], _input, treevars[:, i, :], **kwargs
+                    model, tree[0], _input, tree_vars[:, i, :], **kwargs
                 )
             )
         self.estimators_ = estimators
 
+        constant = predictor.init_.constant_
         model.addConstr(
-            output == predictor.learning_rate * treevars.sum(axis=1) + constant[0][0]
+            output == predictor.learning_rate * tree_vars.sum(axis=1) + constant[0][0]
         )
 
     def print_stats(self, abbrev=False, file=None):
@@ -133,7 +140,7 @@ class GradientBoostingRegressorConstr(SKgetter, AbstractPredictorConstr):
             Text stream to which output should be redirected. By default sys.stdout.
         """
         super().print_stats(abbrev=abbrev, file=file)
-        if abbrev:
+        if abbrev or self._no_debug:
             return
         print(file=file)
 
